@@ -4,23 +4,23 @@ from __future__ import absolute_import
 
 # import apis into api package
 from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi
+from pulpcore.client.pulp_ansible.api.api_collections_api import ApiCollectionsApi
+from pulpcore.client.pulp_ansible.api.api_roles_api import ApiRolesApi
 from pulpcore.client.pulp_ansible.api.collection_import_api import CollectionImportApi
 from pulpcore.client.pulp_ansible.api.content_collection_versions_api import ContentCollectionVersionsApi
 from pulpcore.client.pulp_ansible.api.content_roles_api import ContentRolesApi
 from pulpcore.client.pulp_ansible.api.distributions_ansible_api import DistributionsAnsibleApi
-from pulpcore.client.pulp_ansible.api.galaxy_collection_list_api import GalaxyCollectionListApi
 from pulpcore.client.pulp_ansible.api.galaxy_detail_api import GalaxyDetailApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApiApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_collections_api import PulpAnsibleGalaxyApiCollectionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v2_versions_api import PulpAnsibleGalaxyApiV2VersionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_api import PulpAnsibleGalaxyApiV3CollectionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_certified_api import PulpAnsibleGalaxyApiV3CollectionsCertifiedApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_docs_blob_api import PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_versions_api import PulpAnsibleGalaxyApiV3VersionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi
 from pulpcore.client.pulp_ansible.api.remotes_collection_api import RemotesCollectionApi
 from pulpcore.client.pulp_ansible.api.remotes_role_api import RemotesRoleApi
 from pulpcore.client.pulp_ansible.api.repositories_ansible_api import RepositoriesAnsibleApi
 from pulpcore.client.pulp_ansible.api.repositories_ansible_versions_api import RepositoriesAnsibleVersionsApi
-from pulpcore.client.pulp_ansible.api.role_list_api import RoleListApi
-from pulpcore.client.pulp_ansible.api.v1_roles_api import V1RolesApi
-from pulpcore.client.pulp_ansible.api.v2_collections_api import V2CollectionsApi
+from pulpcore.client.pulp_ansible.api.versions_api import VersionsApi
